@@ -1,15 +1,14 @@
 #!/usr/bin/env seed
-Seed.import_namespace("Gtk");
-Seed.import_namespace("Gio");
-Seed.import_namespace("Notify");
+Gtk = imports.gi.Gtk;
+Gio = imports.gi.Gio;
+Notify = imports.gi.Notify;
 
-Gtk.init(null, null);
+Gtk.init(Seed.argv);
 
-function file_changed(monitor, child, other, event)
-{
-    var notification = 
+function file_changed(monitor, child, other, event){
+    var notification =
 	new Notify.Notification({summary: "File Notification",
-                                 body : "It's not clear what notification system this file is providing an example of." });
+				 body : "It's not clear what notification system this file is providing an example of." });
     notification.set_timeout(5000);
     notification.show();
 }
@@ -24,3 +23,4 @@ monitor.signal.changed.connect(file_changed);
 
 Gtk.main();
 
+
