@@ -120,10 +120,9 @@ seed_gobject_constructor_invoked (JSContextRef ctx,
 
   if (argumentCount > 1)
     {
-      gchar *mes = g_strdup_printf ("Constructor expects"
-				    " 1 argument, got %Zd", argumentCount);
-      seed_make_exception (ctx, exception, "ArgumentError", mes);
-      g_free (mes);
+      seed_make_exception (ctx, exception, "ArgumentError", 
+			   "Constructor expects"
+			   " 1 argument, got %zd", argumentCount);
 
       return (JSObjectRef) JSValueMakeNull (ctx);
     }
@@ -159,12 +158,10 @@ seed_gobject_constructor_invoked (JSContextRef ctx,
       param_spec = g_object_class_find_property (oclass, prop_name);
       if (param_spec == NULL)
 	{
-	  gchar *mes =
-	    g_strdup_printf ("Invalid property for construction: %s",
-			     prop_name);
-	  seed_make_exception (ctx, exception, "PropertyError", mes);
+	  seed_make_exception (ctx, exception, "PropertyError", 
+			       "Invalid property for construction: %s",
+			       prop_name);
 
-	  g_free (mes);
 	  g_free (params);
 
 	  JSPropertyNameArrayRelease (jsprops);
@@ -233,10 +230,9 @@ seed_gobject_equals (JSContextRef ctx,
 
   if (argumentCount != 1)
     {
-      gchar *mes = g_strdup_printf ("GObject equals comparison expected"
-				    " 1 argument, got %Zd", argumentCount);
-      seed_make_exception (ctx, exception, "ArgumentError", mes);
-      g_free (mes);
+      seed_make_exception (ctx, exception, "ArgumentError", 
+			   "GObject equals comparison expected"
+			   " 1 argument, got %zd", argumentCount);
 
       return JSValueMakeNull (ctx);
     }
@@ -271,6 +267,55 @@ seed_gobject_method_finalize (JSObjectRef method)
     g_base_info_unref (info);
 }
 
+typedef void (*InitMethodCallback) (gint *argc, gchar ***argv);
+
+static JSValueRef
+seed_gobject_init_method_invoked (JSContextRef ctx,
+				  JSObjectRef function,
+				  JSObjectRef this_object,
+				  size_t argumentCount,
+				  const JSValueRef arguments[],
+				  JSValueRef * exception)
+{
+  GIBaseInfo *info;
+  GTypelib *typelib;
+  InitMethodCallback c;
+  SeedArgvPrivates *priv;
+  if (argumentCount != 1 && argumentCount != 2)
+    {
+      seed_make_exception (ctx, exception, 
+			   "ArgumentError", "init method expects 1 argument, got %zd", 
+			   argumentCount);
+      return JSValueMakeUndefined (ctx);
+    }
+
+  // TODO: In future support all arrays.Through a seperate code path.
+  if (!argumentCount == 2)
+    {
+      if (JSValueIsNull (ctx, arguments[0]) || !JSValueIsObject (ctx, arguments[0]) ||
+	  !JSValueIsObjectOfClass (ctx, arguments[0], seed_argv_class))
+	{
+	  seed_make_exception (ctx, exception,
+			       "ArgumentError", "init method expects an argv object as argument");
+	}
+    }
+  
+  info = JSObjectGetPrivate (function);
+  typelib = g_base_info_get_typelib (info);
+  g_typelib_symbol (typelib, g_function_info_get_symbol ((GIFunctionInfo *)info), (gpointer *)&c);
+  // Backwards compatibility
+  if (argumentCount == 2)
+    {
+      c(NULL, NULL);
+      return JSValueMakeUndefined (ctx);
+    }
+
+  priv = JSObjectGetPrivate ((JSObjectRef)arguments[0]);
+  c(&priv->argc, &priv->argv);
+    
+  return JSValueMakeUndefined (ctx);
+}
+
 static JSValueRef
 seed_gobject_method_invoked (JSContextRef ctx,
 			     JSObjectRef function,
@@ -329,14 +374,13 @@ seed_gobject_method_invoked (JSContextRef ctx,
 				      type_info,
 				      &in_args[n_in_args++], exception))
 	    {
-	      gchar *mes =
-		g_strdup_printf
-		("Unable to make argument %d for" " function: %s. \n",
-		 i + 1,
-		 g_base_info_get_name ((GIBaseInfo *) info));
-	      seed_make_exception (ctx, exception, "ArgumentError", mes);
+	      seed_make_exception (ctx, exception, 
+				   "ArgumentError", 
+				   "Unable to make argument %d for" 
+				   " function: %s. \n",
+				   i + 1,
+				   g_base_info_get_name ((GIBaseInfo *) info));
 
-	      g_free (mes);
 	      g_base_info_unref ((GIBaseInfo *) type_info);
 	      g_base_info_unref ((GIBaseInfo *) arg_info);
 	      g_free (in_args);
@@ -374,7 +418,7 @@ seed_gobject_method_invoked (JSContextRef ctx,
       type_info = g_callable_info_get_return_type ((GICallableInfo *) info);
       tag = g_type_info_get_tag (type_info);
       if (tag == GI_TYPE_TAG_VOID)
-	retval_ref = JSValueMakeNull (ctx);
+	retval_ref = JSValueMakeUndefined (ctx);
       else
 	{
 	  GIBaseInfo *interface;
@@ -850,7 +894,8 @@ seed_gobject_set_property (JSContextRef context,
   g_object_set_property (obj, cproperty_name, &gval);
   if (glib_message != 0)
     {
-      seed_make_exception (context, exception, "PropertyError", glib_message);
+      seed_make_exception (context, exception, "PropertyError", 
+			   glib_message, NULL);
 
       return FALSE;
     }
@@ -906,6 +951,29 @@ seed_gi_import_namespace (JSContextRef ctx,
   return JSValueMakeNull (ctx);
 }
 
+static JSValueRef
+seed_gobject_constructor_convert_to_type (JSContextRef ctx,
+					  JSObjectRef object,
+					  JSType type,
+					  JSValueRef *exception)
+{
+  GType gtype;
+  
+  if (type == kJSTypeString)
+    {
+      JSValueRef ret;
+      gchar *as_string;
+      gtype = (GType) JSObjectGetPrivate (object);
+      
+      as_string = g_strdup_printf("[gobject_constructor %s]", g_type_name (gtype));
+      ret = seed_value_from_string (ctx, as_string, exception);
+      g_free (as_string);
+      
+      return ret;
+    }
+  return FALSE;
+}
+
 JSStaticFunction gobject_static_funcs[] = {
   {"equals", seed_gobject_equals, 0}
   ,
@@ -954,6 +1022,26 @@ JSClassDefinition gobject_method_def = {
   NULL				/* Convert To Type */
 };
 
+JSClassDefinition gobject_init_method_def = {
+  0,				/* Version, always 0 */
+  0,
+  "init_method",		/* Class Name */
+  NULL,				/* Parent Class */
+  NULL,				/* Static Values */
+  NULL,				/* Static Functions */
+  NULL,
+  seed_gobject_method_finalize,	/* Finalize */
+  NULL,				/* Has Property */
+  NULL,				/* Get Property */
+  NULL,				/* Set Property */
+  NULL,				/* Delete Property */
+  NULL,				/* Get Property Names */
+  seed_gobject_init_method_invoked,	/* Call As Function */
+  NULL,				/* Call As Constructor */
+  NULL,				/* Has Instance */
+  NULL				/* Convert To Type */
+};
+
 JSClassDefinition seed_callback_def = {
   0,				/* Version, always 0 */
   0,
@@ -991,7 +1079,7 @@ JSClassDefinition gobject_constructor_def = {
   NULL,				/* Call As Function */
   seed_gobject_constructor_invoked,	/* Call As Constructor */
   NULL,				/* Has Instance */
-  NULL				/* Convert To Type */
+  seed_gobject_constructor_convert_to_type
 };
 
 JSClassDefinition gobject_named_constructor_def = {
@@ -1011,7 +1099,7 @@ JSClassDefinition gobject_named_constructor_def = {
   NULL,				/* Call As Function */
   seed_gobject_named_constructor_invoked,	/* Call As Constructor */
   NULL,				/* Has Instance */
-  NULL				/* Convert To Type */
+  seed_gobject_constructor_convert_to_type
 };
 
 JSClassDefinition struct_constructor_def = {
@@ -1225,6 +1313,8 @@ seed_init (gint * argc, gchar *** argv)
   JSClassRetain (seed_callback_class);
   seed_struct_constructor_class = JSClassCreate (&struct_constructor_def);
   JSClassRetain (seed_struct_constructor_class);
+  gobject_init_method_class = JSClassCreate (&gobject_init_method_def);
+  JSClassRetain (gobject_init_method_class);
 
   g_type_set_qdata (G_TYPE_OBJECT, qname, gobject_class);
 
@@ -1308,6 +1398,8 @@ seed_init_with_context_group (gint * argc,
   JSClassRetain (seed_callback_class);
   seed_struct_constructor_class = JSClassCreate (&struct_constructor_def);
   JSClassRetain (seed_struct_constructor_class);
+  gobject_init_method_class = JSClassCreate (&gobject_init_method_def);
+  JSClassRetain (gobject_init_method_class);
 
   g_type_set_qdata (G_TYPE_OBJECT, qname, gobject_class);
 
