@@ -17,11 +17,13 @@
 
 #include "seed-private.h"
 #include <dlfcn.h>
+#include <string.h>
 
 JSClassRef gobject_class;
 JSClassRef gobject_method_class;
 JSClassRef gobject_constructor_class;
 JSClassRef seed_callback_class;
+JSClassRef gobject_init_method_class;
 SeedEngine *eng;
 
 static gboolean
@@ -555,12 +557,9 @@ seed_gi_make_argument (JSContextRef ctx,
 	    arg->v_long = seed_value_to_long (ctx, value, exception);
 	    if (!(interface_type == GI_INFO_TYPE_FLAGS) && !seed_validate_enum ((GIEnumInfo *)interface, arg->v_long))
 	      {
-		gchar *message = 
-		  g_strdup_printf ("Enum value: %ld is out of range", 
-				   arg->v_long);
-		
 		seed_make_exception (ctx, exception, "EnumRange",
-				     message);
+				     "Enum value: %ld is out of range", 
+				     arg->v_long);
 		g_base_info_unref (interface);
 		
 		return FALSE;
@@ -602,7 +601,7 @@ seed_gi_make_argument (JSContextRef ctx,
 		    if (JSObjectIsFunction (ctx, (JSObjectRef) value))
 		      {
 			arg->v_pointer =
-			  seed_make_gclosure (ctx, (JSObjectRef) value, 0);
+				seed_closure_new (ctx, (JSObjectRef) value, NULL, NULL);
 		      }
 		  }
 		else
@@ -736,7 +735,7 @@ seed_gi_argument_make_js (JSContextRef ctx,
   switch (gi_tag)
     {
     case GI_TYPE_TAG_VOID:
-      return 0;
+      return JSValueMakeUndefined (ctx);
     case GI_TYPE_TAG_BOOLEAN:
       return seed_value_from_boolean (ctx, arg->v_boolean, exception);
     case GI_TYPE_TAG_INT8:
@@ -977,6 +976,8 @@ seed_gvalue_from_seed_value (JSContextRef ctx,
 			     JSValueRef val,
 			     GType type, GValue * ret, JSValueRef * exception)
 {
+  if (G_IS_VALUE (ret))
+    g_value_unset (ret);
   switch (type)
     {
     case G_TYPE_BOOLEAN:
@@ -1769,14 +1770,17 @@ seed_value_to_string (JSContextRef ctx,
 
   if (val == NULL)
     return NULL;
-
-  else if (JSValueIsNull (ctx, val) || JSValueIsUndefined (ctx, val))
+  else if (JSValueIsUndefined (ctx, val))
+    {
+      buf = g_strdup ("[undefined]");
+    }
+  else if (JSValueIsNull (ctx, val))
     {
       buf = g_strdup ("[null]");
     }
   else if (JSValueIsBoolean (ctx, val) || JSValueIsNumber (ctx, val))
     {
-      buf = g_strdup_printf ("%lf", JSValueToNumber (ctx, val, NULL));
+      buf = g_strdup_printf ("%.15g", JSValueToNumber (ctx, val, NULL));
     }
   else
     {
@@ -1826,6 +1830,23 @@ seed_value_from_string (JSContextRef ctx,
   return valstr;
 }
 
+JSValueRef
+seed_value_from_binary_string (JSContextRef ctx,
+			       const gchar *bytes,
+			       gint n_bytes,
+			       JSValueRef *exception)
+{
+  JSValueRef ret;
+
+  gchar *nstr = g_alloca ((n_bytes +1)*sizeof(gchar));
+  strncpy (nstr, bytes, n_bytes);
+  nstr[n_bytes] = '\0';
+  
+  ret = seed_value_from_string (ctx, nstr, exception);
+  
+  return ret;
+}
+
 gchar *
 seed_value_to_filename (JSContextRef ctx,
 			JSValueRef val, JSValueRef * exception)
