@@ -1,11 +1,11 @@
 #!/usr/bin/env seed
 // Returns: 0
 // STDIN:
-// STDOUT:0.000000\n1.000000
+// STDOUT:0\n1
 // STDERR:
 
 Gtk = imports.gi.Gtk;
-Gtk.init(null, null);
+Gtk.init(Seed.argv);
 
 var a = new Gtk.Button();
 var b = new Gtk.Button();
